# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CriterionErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CriterionError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CriterionErrorEnum.CriterionError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CriterionErrorEnum.CriterionError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CriterionErrorEnum.CriterionError]]: ...
        UNSPECIFIED = typing___cast(CriterionErrorEnum.CriterionError, 0)
        UNKNOWN = typing___cast(CriterionErrorEnum.CriterionError, 1)
        CONCRETE_TYPE_REQUIRED = typing___cast(CriterionErrorEnum.CriterionError, 2)
        INVALID_EXCLUDED_CATEGORY = typing___cast(CriterionErrorEnum.CriterionError, 3)
        INVALID_KEYWORD_TEXT = typing___cast(CriterionErrorEnum.CriterionError, 4)
        KEYWORD_TEXT_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 5)
        KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(CriterionErrorEnum.CriterionError, 6)
        KEYWORD_HAS_INVALID_CHARS = typing___cast(CriterionErrorEnum.CriterionError, 7)
        INVALID_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionError, 8)
        INVALID_USER_LIST = typing___cast(CriterionErrorEnum.CriterionError, 9)
        INVALID_USER_INTEREST = typing___cast(CriterionErrorEnum.CriterionError, 10)
        INVALID_FORMAT_FOR_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionError, 11)
        PLACEMENT_URL_IS_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 12)
        PLACEMENT_URL_HAS_ILLEGAL_CHAR = typing___cast(CriterionErrorEnum.CriterionError, 13)
        PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = typing___cast(CriterionErrorEnum.CriterionError, 14)
        PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = typing___cast(CriterionErrorEnum.CriterionError, 15)
        INVALID_TOPIC_PATH = typing___cast(CriterionErrorEnum.CriterionError, 16)
        INVALID_YOUTUBE_CHANNEL_ID = typing___cast(CriterionErrorEnum.CriterionError, 17)
        INVALID_YOUTUBE_VIDEO_ID = typing___cast(CriterionErrorEnum.CriterionError, 18)
        YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = typing___cast(CriterionErrorEnum.CriterionError, 19)
        YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = typing___cast(CriterionErrorEnum.CriterionError, 20)
        YOUTUBE_URL_UNSUPPORTED = typing___cast(CriterionErrorEnum.CriterionError, 21)
        CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 22)
        CANNOT_ADD_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 23)
        INVALID_PRODUCT_FILTER = typing___cast(CriterionErrorEnum.CriterionError, 24)
        PRODUCT_FILTER_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 25)
        CANNOT_EXCLUDE_SIMILAR_USER_LIST = typing___cast(CriterionErrorEnum.CriterionError, 26)
        CANNOT_ADD_CLOSED_USER_LIST = typing___cast(CriterionErrorEnum.CriterionError, 27)
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 28)
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 29)
        CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 30)
        CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 31)
        CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 32)
        CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 33)
        INVALID_CUSTOM_AFFINITY = typing___cast(CriterionErrorEnum.CriterionError, 96)
        INVALID_CUSTOM_INTENT = typing___cast(CriterionErrorEnum.CriterionError, 97)
        INVALID_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionError, 34)
        INVALID_IP_FORMAT = typing___cast(CriterionErrorEnum.CriterionError, 35)
        INVALID_MOBILE_APP = typing___cast(CriterionErrorEnum.CriterionError, 36)
        INVALID_MOBILE_APP_CATEGORY = typing___cast(CriterionErrorEnum.CriterionError, 37)
        INVALID_CRITERION_ID = typing___cast(CriterionErrorEnum.CriterionError, 38)
        CANNOT_TARGET_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 39)
        CANNOT_TARGET_OBSOLETE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 40)
        CRITERION_ID_AND_TYPE_MISMATCH = typing___cast(CriterionErrorEnum.CriterionError, 41)
        INVALID_PROXIMITY_RADIUS = typing___cast(CriterionErrorEnum.CriterionError, 42)
        INVALID_PROXIMITY_RADIUS_UNITS = typing___cast(CriterionErrorEnum.CriterionError, 43)
        INVALID_STREETADDRESS_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 44)
        INVALID_CITYNAME_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 45)
        INVALID_REGIONCODE_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 46)
        INVALID_REGIONNAME_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 47)
        INVALID_POSTALCODE_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 48)
        INVALID_COUNTRY_CODE = typing___cast(CriterionErrorEnum.CriterionError, 49)
        INVALID_LATITUDE = typing___cast(CriterionErrorEnum.CriterionError, 50)
        INVALID_LONGITUDE = typing___cast(CriterionErrorEnum.CriterionError, 51)
        PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = typing___cast(CriterionErrorEnum.CriterionError, 52)
        INVALID_PROXIMITY_ADDRESS = typing___cast(CriterionErrorEnum.CriterionError, 53)
        INVALID_USER_DOMAIN_NAME = typing___cast(CriterionErrorEnum.CriterionError, 54)
        CRITERION_PARAMETER_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 55)
        AD_SCHEDULE_TIME_INTERVALS_OVERLAP = typing___cast(CriterionErrorEnum.CriterionError, 56)
        AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = typing___cast(CriterionErrorEnum.CriterionError, 57)
        AD_SCHEDULE_INVALID_TIME_INTERVAL = typing___cast(CriterionErrorEnum.CriterionError, 58)
        AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = typing___cast(CriterionErrorEnum.CriterionError, 59)
        AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = typing___cast(CriterionErrorEnum.CriterionError, 60)
        CANNOT_BID_MODIFY_CRITERION_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 61)
        CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = typing___cast(CriterionErrorEnum.CriterionError, 62)
        CANNOT_BID_MODIFY_NEGATIVE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 63)
        BID_MODIFIER_ALREADY_EXISTS = typing___cast(CriterionErrorEnum.CriterionError, 64)
        FEED_ID_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionError, 65)
        ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 66)
        CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = typing___cast(CriterionErrorEnum.CriterionError, 67)
        CANNOT_EXCLUDE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 68)
        CANNOT_REMOVE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 69)
        PRODUCT_SCOPE_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 70)
        PRODUCT_SCOPE_TOO_MANY_DIMENSIONS = typing___cast(CriterionErrorEnum.CriterionError, 71)
        PRODUCT_PARTITION_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 72)
        PRODUCT_PARTITION_TOO_MANY_DIMENSIONS = typing___cast(CriterionErrorEnum.CriterionError, 73)
        INVALID_PRODUCT_DIMENSION = typing___cast(CriterionErrorEnum.CriterionError, 74)
        INVALID_PRODUCT_DIMENSION_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 75)
        INVALID_PRODUCT_BIDDING_CATEGORY = typing___cast(CriterionErrorEnum.CriterionError, 76)
        MISSING_SHOPPING_SETTING = typing___cast(CriterionErrorEnum.CriterionError, 77)
        INVALID_MATCHING_FUNCTION = typing___cast(CriterionErrorEnum.CriterionError, 78)
        LOCATION_FILTER_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionError, 79)
        INVALID_FEED_FOR_LOCATION_FILTER = typing___cast(CriterionErrorEnum.CriterionError, 98)
        LOCATION_FILTER_INVALID = typing___cast(CriterionErrorEnum.CriterionError, 80)
        CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = typing___cast(CriterionErrorEnum.CriterionError, 81)
        HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 82)
        HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 83)
        FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = typing___cast(CriterionErrorEnum.CriterionError, 84)
        INVALID_WEBPAGE_CONDITION = typing___cast(CriterionErrorEnum.CriterionError, 85)
        INVALID_WEBPAGE_CONDITION_URL = typing___cast(CriterionErrorEnum.CriterionError, 86)
        WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = typing___cast(CriterionErrorEnum.CriterionError, 87)
        WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = typing___cast(CriterionErrorEnum.CriterionError, 88)
        WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionError, 89)
        WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = typing___cast(CriterionErrorEnum.CriterionError, 90)
        WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = typing___cast(CriterionErrorEnum.CriterionError, 91)
        WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = typing___cast(CriterionErrorEnum.CriterionError, 92)
        WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = typing___cast(CriterionErrorEnum.CriterionError, 93)
        WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = typing___cast(CriterionErrorEnum.CriterionError, 94)
        WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = typing___cast(CriterionErrorEnum.CriterionError, 95)
    UNSPECIFIED = typing___cast(CriterionErrorEnum.CriterionError, 0)
    UNKNOWN = typing___cast(CriterionErrorEnum.CriterionError, 1)
    CONCRETE_TYPE_REQUIRED = typing___cast(CriterionErrorEnum.CriterionError, 2)
    INVALID_EXCLUDED_CATEGORY = typing___cast(CriterionErrorEnum.CriterionError, 3)
    INVALID_KEYWORD_TEXT = typing___cast(CriterionErrorEnum.CriterionError, 4)
    KEYWORD_TEXT_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 5)
    KEYWORD_HAS_TOO_MANY_WORDS = typing___cast(CriterionErrorEnum.CriterionError, 6)
    KEYWORD_HAS_INVALID_CHARS = typing___cast(CriterionErrorEnum.CriterionError, 7)
    INVALID_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionError, 8)
    INVALID_USER_LIST = typing___cast(CriterionErrorEnum.CriterionError, 9)
    INVALID_USER_INTEREST = typing___cast(CriterionErrorEnum.CriterionError, 10)
    INVALID_FORMAT_FOR_PLACEMENT_URL = typing___cast(CriterionErrorEnum.CriterionError, 11)
    PLACEMENT_URL_IS_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 12)
    PLACEMENT_URL_HAS_ILLEGAL_CHAR = typing___cast(CriterionErrorEnum.CriterionError, 13)
    PLACEMENT_URL_HAS_MULTIPLE_SITES_IN_LINE = typing___cast(CriterionErrorEnum.CriterionError, 14)
    PLACEMENT_IS_NOT_AVAILABLE_FOR_TARGETING_OR_EXCLUSION = typing___cast(CriterionErrorEnum.CriterionError, 15)
    INVALID_TOPIC_PATH = typing___cast(CriterionErrorEnum.CriterionError, 16)
    INVALID_YOUTUBE_CHANNEL_ID = typing___cast(CriterionErrorEnum.CriterionError, 17)
    INVALID_YOUTUBE_VIDEO_ID = typing___cast(CriterionErrorEnum.CriterionError, 18)
    YOUTUBE_VERTICAL_CHANNEL_DEPRECATED = typing___cast(CriterionErrorEnum.CriterionError, 19)
    YOUTUBE_DEMOGRAPHIC_CHANNEL_DEPRECATED = typing___cast(CriterionErrorEnum.CriterionError, 20)
    YOUTUBE_URL_UNSUPPORTED = typing___cast(CriterionErrorEnum.CriterionError, 21)
    CANNOT_EXCLUDE_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 22)
    CANNOT_ADD_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 23)
    INVALID_PRODUCT_FILTER = typing___cast(CriterionErrorEnum.CriterionError, 24)
    PRODUCT_FILTER_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 25)
    CANNOT_EXCLUDE_SIMILAR_USER_LIST = typing___cast(CriterionErrorEnum.CriterionError, 26)
    CANNOT_ADD_CLOSED_USER_LIST = typing___cast(CriterionErrorEnum.CriterionError, 27)
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_ONLY_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 28)
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SEARCH_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 29)
    CANNOT_ADD_DISPLAY_ONLY_LISTS_TO_SHOPPING_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 30)
    CANNOT_ADD_USER_INTERESTS_TO_SEARCH_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 31)
    CANNOT_SET_BIDS_ON_CRITERION_TYPE_IN_SEARCH_CAMPAIGNS = typing___cast(CriterionErrorEnum.CriterionError, 32)
    CANNOT_ADD_URLS_TO_CRITERION_TYPE_FOR_CAMPAIGN_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 33)
    INVALID_CUSTOM_AFFINITY = typing___cast(CriterionErrorEnum.CriterionError, 96)
    INVALID_CUSTOM_INTENT = typing___cast(CriterionErrorEnum.CriterionError, 97)
    INVALID_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionError, 34)
    INVALID_IP_FORMAT = typing___cast(CriterionErrorEnum.CriterionError, 35)
    INVALID_MOBILE_APP = typing___cast(CriterionErrorEnum.CriterionError, 36)
    INVALID_MOBILE_APP_CATEGORY = typing___cast(CriterionErrorEnum.CriterionError, 37)
    INVALID_CRITERION_ID = typing___cast(CriterionErrorEnum.CriterionError, 38)
    CANNOT_TARGET_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 39)
    CANNOT_TARGET_OBSOLETE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 40)
    CRITERION_ID_AND_TYPE_MISMATCH = typing___cast(CriterionErrorEnum.CriterionError, 41)
    INVALID_PROXIMITY_RADIUS = typing___cast(CriterionErrorEnum.CriterionError, 42)
    INVALID_PROXIMITY_RADIUS_UNITS = typing___cast(CriterionErrorEnum.CriterionError, 43)
    INVALID_STREETADDRESS_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 44)
    INVALID_CITYNAME_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 45)
    INVALID_REGIONCODE_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 46)
    INVALID_REGIONNAME_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 47)
    INVALID_POSTALCODE_LENGTH = typing___cast(CriterionErrorEnum.CriterionError, 48)
    INVALID_COUNTRY_CODE = typing___cast(CriterionErrorEnum.CriterionError, 49)
    INVALID_LATITUDE = typing___cast(CriterionErrorEnum.CriterionError, 50)
    INVALID_LONGITUDE = typing___cast(CriterionErrorEnum.CriterionError, 51)
    PROXIMITY_GEOPOINT_AND_ADDRESS_BOTH_CANNOT_BE_NULL = typing___cast(CriterionErrorEnum.CriterionError, 52)
    INVALID_PROXIMITY_ADDRESS = typing___cast(CriterionErrorEnum.CriterionError, 53)
    INVALID_USER_DOMAIN_NAME = typing___cast(CriterionErrorEnum.CriterionError, 54)
    CRITERION_PARAMETER_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 55)
    AD_SCHEDULE_TIME_INTERVALS_OVERLAP = typing___cast(CriterionErrorEnum.CriterionError, 56)
    AD_SCHEDULE_INTERVAL_CANNOT_SPAN_MULTIPLE_DAYS = typing___cast(CriterionErrorEnum.CriterionError, 57)
    AD_SCHEDULE_INVALID_TIME_INTERVAL = typing___cast(CriterionErrorEnum.CriterionError, 58)
    AD_SCHEDULE_EXCEEDED_INTERVALS_PER_DAY_LIMIT = typing___cast(CriterionErrorEnum.CriterionError, 59)
    AD_SCHEDULE_CRITERION_ID_MISMATCHING_FIELDS = typing___cast(CriterionErrorEnum.CriterionError, 60)
    CANNOT_BID_MODIFY_CRITERION_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 61)
    CANNOT_BID_MODIFY_CRITERION_CAMPAIGN_OPTED_OUT = typing___cast(CriterionErrorEnum.CriterionError, 62)
    CANNOT_BID_MODIFY_NEGATIVE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 63)
    BID_MODIFIER_ALREADY_EXISTS = typing___cast(CriterionErrorEnum.CriterionError, 64)
    FEED_ID_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionError, 65)
    ACCOUNT_INELIGIBLE_FOR_CRITERIA_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 66)
    CRITERIA_TYPE_INVALID_FOR_BIDDING_STRATEGY = typing___cast(CriterionErrorEnum.CriterionError, 67)
    CANNOT_EXCLUDE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 68)
    CANNOT_REMOVE_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 69)
    PRODUCT_SCOPE_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 70)
    PRODUCT_SCOPE_TOO_MANY_DIMENSIONS = typing___cast(CriterionErrorEnum.CriterionError, 71)
    PRODUCT_PARTITION_TOO_LONG = typing___cast(CriterionErrorEnum.CriterionError, 72)
    PRODUCT_PARTITION_TOO_MANY_DIMENSIONS = typing___cast(CriterionErrorEnum.CriterionError, 73)
    INVALID_PRODUCT_DIMENSION = typing___cast(CriterionErrorEnum.CriterionError, 74)
    INVALID_PRODUCT_DIMENSION_TYPE = typing___cast(CriterionErrorEnum.CriterionError, 75)
    INVALID_PRODUCT_BIDDING_CATEGORY = typing___cast(CriterionErrorEnum.CriterionError, 76)
    MISSING_SHOPPING_SETTING = typing___cast(CriterionErrorEnum.CriterionError, 77)
    INVALID_MATCHING_FUNCTION = typing___cast(CriterionErrorEnum.CriterionError, 78)
    LOCATION_FILTER_NOT_ALLOWED = typing___cast(CriterionErrorEnum.CriterionError, 79)
    INVALID_FEED_FOR_LOCATION_FILTER = typing___cast(CriterionErrorEnum.CriterionError, 98)
    LOCATION_FILTER_INVALID = typing___cast(CriterionErrorEnum.CriterionError, 80)
    CANNOT_ATTACH_CRITERIA_AT_CAMPAIGN_AND_ADGROUP = typing___cast(CriterionErrorEnum.CriterionError, 81)
    HOTEL_LENGTH_OF_STAY_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 82)
    HOTEL_ADVANCE_BOOKING_WINDOW_OVERLAPS_WITH_EXISTING_CRITERION = typing___cast(CriterionErrorEnum.CriterionError, 83)
    FIELD_INCOMPATIBLE_WITH_NEGATIVE_TARGETING = typing___cast(CriterionErrorEnum.CriterionError, 84)
    INVALID_WEBPAGE_CONDITION = typing___cast(CriterionErrorEnum.CriterionError, 85)
    INVALID_WEBPAGE_CONDITION_URL = typing___cast(CriterionErrorEnum.CriterionError, 86)
    WEBPAGE_CONDITION_URL_CANNOT_BE_EMPTY = typing___cast(CriterionErrorEnum.CriterionError, 87)
    WEBPAGE_CONDITION_URL_UNSUPPORTED_PROTOCOL = typing___cast(CriterionErrorEnum.CriterionError, 88)
    WEBPAGE_CONDITION_URL_CANNOT_BE_IP_ADDRESS = typing___cast(CriterionErrorEnum.CriterionError, 89)
    WEBPAGE_CONDITION_URL_DOMAIN_NOT_CONSISTENT_WITH_CAMPAIGN_SETTING = typing___cast(CriterionErrorEnum.CriterionError, 90)
    WEBPAGE_CONDITION_URL_CANNOT_BE_PUBLIC_SUFFIX = typing___cast(CriterionErrorEnum.CriterionError, 91)
    WEBPAGE_CONDITION_URL_INVALID_PUBLIC_SUFFIX = typing___cast(CriterionErrorEnum.CriterionError, 92)
    WEBPAGE_CONDITION_URL_VALUE_TRACK_VALUE_NOT_SUPPORTED = typing___cast(CriterionErrorEnum.CriterionError, 93)
    WEBPAGE_CRITERION_URL_EQUALS_CAN_HAVE_ONLY_ONE_CONDITION = typing___cast(CriterionErrorEnum.CriterionError, 94)
    WEBPAGE_CRITERION_NOT_SUPPORTED_ON_NON_DSA_AD_GROUP = typing___cast(CriterionErrorEnum.CriterionError, 95)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CriterionErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.keyword_plan_network_pb2 import (
    KeywordPlanNetworkEnum as google___ads___googleads___v2___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class KeywordPlanCampaign(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    keyword_plan_network = ... # type: google___ads___googleads___v2___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetwork

    @property
    def keyword_plan(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def language_constants(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___protobuf___wrappers_pb2___StringValue]: ...

    @property
    def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def geo_targets(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[KeywordPlanGeoTarget]: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        keyword_plan : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        language_constants : typing___Optional[typing___Iterable[google___protobuf___wrappers_pb2___StringValue]] = None,
        keyword_plan_network : typing___Optional[google___ads___googleads___v2___enums___keyword_plan_network_pb2___KeywordPlanNetworkEnum.KeywordPlanNetwork] = None,
        cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        geo_targets : typing___Optional[typing___Iterable[KeywordPlanGeoTarget]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanCampaign: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",u"id",u"keyword_plan",u"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",u"geo_targets",u"id",u"keyword_plan",u"keyword_plan_network",u"language_constants",u"name",u"resource_name"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",b"cpc_bid_micros",u"id",b"id",u"keyword_plan",b"keyword_plan",u"name",b"name"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"cpc_bid_micros",b"cpc_bid_micros",u"geo_targets",b"geo_targets",u"id",b"id",u"keyword_plan",b"keyword_plan",u"keyword_plan_network",b"keyword_plan_network",u"language_constants",b"language_constants",u"name",b"name",u"resource_name",b"resource_name"]) -> None: ...

class KeywordPlanGeoTarget(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def geo_target_constant(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        geo_target_constant : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> KeywordPlanGeoTarget: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"geo_target_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"geo_target_constant",b"geo_target_constant"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"geo_target_constant",b"geo_target_constant"]) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v2.services.transports.google_ads_field_service_grpc_transport import GoogleAdsFieldServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar, Iterator
from google.ads.google_ads.v2.proto.resources.google_ads_field_pb2 import GoogleAdsField

class GoogleAdsFieldServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> GoogleAdsFieldServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> GoogleAdsFieldServiceClient: ...
    @classmethod
    def google_ads_field_path(cls, google_ads_field: Any): ...
    transport: Union[GoogleAdsFieldServiceGrpcTransport, Callable[[Credentials, type], GoogleAdsFieldServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[GoogleAdsFieldServiceGrpcTransport, Callable[[Credentials, type], GoogleAdsFieldServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def get_google_ads_field(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> GoogleAdsField: ...
    def search_google_ads_fields(self, query: str, page_size: Optional[int] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Iterator[GoogleAdsField]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class ConversionAdjustmentUploadErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class ConversionAdjustmentUploadError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError]]: ...
        UNSPECIFIED = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 0)
        UNKNOWN = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 1)
        TOO_RECENT_CONVERSION_ACTION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 2)
        INVALID_CONVERSION_ACTION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 3)
        CONVERSION_ALREADY_RETRACTED = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 4)
        CONVERSION_NOT_FOUND = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 5)
        CONVERSION_EXPIRED = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 6)
        ADJUSTMENT_PRECEDES_CONVERSION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 7)
        MORE_RECENT_RESTATEMENT_FOUND = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 8)
        TOO_RECENT_CONVERSION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 9)
        CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 10)
    UNSPECIFIED = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 0)
    UNKNOWN = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 1)
    TOO_RECENT_CONVERSION_ACTION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 2)
    INVALID_CONVERSION_ACTION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 3)
    CONVERSION_ALREADY_RETRACTED = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 4)
    CONVERSION_NOT_FOUND = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 5)
    CONVERSION_EXPIRED = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 6)
    ADJUSTMENT_PRECEDES_CONVERSION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 7)
    MORE_RECENT_RESTATEMENT_FOUND = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 8)
    TOO_RECENT_CONVERSION = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 9)
    CANNOT_RESTATE_CONVERSION_ACTION_THAT_ALWAYS_USES_DEFAULT_CONVERSION_VALUE = typing___cast(ConversionAdjustmentUploadErrorEnum.ConversionAdjustmentUploadError, 10)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionAdjustmentUploadErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.bidding_pb2 import (
    EnhancedCpc as google___ads___googleads___v1___common___bidding_pb2___EnhancedCpc,
    PageOnePromoted as google___ads___googleads___v1___common___bidding_pb2___PageOnePromoted,
    TargetCpa as google___ads___googleads___v1___common___bidding_pb2___TargetCpa,
    TargetImpressionShare as google___ads___googleads___v1___common___bidding_pb2___TargetImpressionShare,
    TargetOutrankShare as google___ads___googleads___v1___common___bidding_pb2___TargetOutrankShare,
    TargetRoas as google___ads___googleads___v1___common___bidding_pb2___TargetRoas,
    TargetSpend as google___ads___googleads___v1___common___bidding_pb2___TargetSpend,
)

from google.ads.google_ads.v1.proto.enums.bidding_strategy_status_pb2 import (
    BiddingStrategyStatusEnum as google___ads___googleads___v1___enums___bidding_strategy_status_pb2___BiddingStrategyStatusEnum,
)

from google.ads.google_ads.v1.proto.enums.bidding_strategy_type_pb2 import (
    BiddingStrategyTypeEnum as google___ads___googleads___v1___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class BiddingStrategy(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    status = ... # type: google___ads___googleads___v1___enums___bidding_strategy_status_pb2___BiddingStrategyStatusEnum.BiddingStrategyStatus
    type = ... # type: google___ads___googleads___v1___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def campaign_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def non_removed_campaign_count(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def enhanced_cpc(self) -> google___ads___googleads___v1___common___bidding_pb2___EnhancedCpc: ...

    @property
    def page_one_promoted(self) -> google___ads___googleads___v1___common___bidding_pb2___PageOnePromoted: ...

    @property
    def target_cpa(self) -> google___ads___googleads___v1___common___bidding_pb2___TargetCpa: ...

    @property
    def target_impression_share(self) -> google___ads___googleads___v1___common___bidding_pb2___TargetImpressionShare: ...

    @property
    def target_outrank_share(self) -> google___ads___googleads___v1___common___bidding_pb2___TargetOutrankShare: ...

    @property
    def target_roas(self) -> google___ads___googleads___v1___common___bidding_pb2___TargetRoas: ...

    @property
    def target_spend(self) -> google___ads___googleads___v1___common___bidding_pb2___TargetSpend: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        status : typing___Optional[google___ads___googleads___v1___enums___bidding_strategy_status_pb2___BiddingStrategyStatusEnum.BiddingStrategyStatus] = None,
        type : typing___Optional[google___ads___googleads___v1___enums___bidding_strategy_type_pb2___BiddingStrategyTypeEnum.BiddingStrategyType] = None,
        campaign_count : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        non_removed_campaign_count : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        enhanced_cpc : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___EnhancedCpc] = None,
        page_one_promoted : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___PageOnePromoted] = None,
        target_cpa : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___TargetCpa] = None,
        target_impression_share : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___TargetImpressionShare] = None,
        target_outrank_share : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___TargetOutrankShare] = None,
        target_roas : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___TargetRoas] = None,
        target_spend : typing___Optional[google___ads___googleads___v1___common___bidding_pb2___TargetSpend] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BiddingStrategy: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_count",u"enhanced_cpc",u"id",u"name",u"non_removed_campaign_count",u"page_one_promoted",u"scheme",u"target_cpa",u"target_impression_share",u"target_outrank_share",u"target_roas",u"target_spend"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_count",u"enhanced_cpc",u"id",u"name",u"non_removed_campaign_count",u"page_one_promoted",u"resource_name",u"scheme",u"status",u"target_cpa",u"target_impression_share",u"target_outrank_share",u"target_roas",u"target_spend",u"type"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"campaign_count",b"campaign_count",u"enhanced_cpc",b"enhanced_cpc",u"id",b"id",u"name",b"name",u"non_removed_campaign_count",b"non_removed_campaign_count",u"page_one_promoted",b"page_one_promoted",u"scheme",b"scheme",u"target_cpa",b"target_cpa",u"target_impression_share",b"target_impression_share",u"target_outrank_share",b"target_outrank_share",u"target_roas",b"target_roas",u"target_spend",b"target_spend"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"campaign_count",b"campaign_count",u"enhanced_cpc",b"enhanced_cpc",u"id",b"id",u"name",b"name",u"non_removed_campaign_count",b"non_removed_campaign_count",u"page_one_promoted",b"page_one_promoted",u"resource_name",b"resource_name",u"scheme",b"scheme",u"status",b"status",u"target_cpa",b"target_cpa",u"target_impression_share",b"target_impression_share",u"target_outrank_share",b"target_outrank_share",u"target_roas",b"target_roas",u"target_spend",b"target_spend",u"type",b"type"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"scheme",b"scheme"]) -> typing_extensions___Literal["enhanced_cpc","page_one_promoted","target_cpa","target_impression_share","target_outrank_share","target_roas","target_spend"]: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MimeTypeEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MimeType(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MimeTypeEnum.MimeType: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MimeTypeEnum.MimeType]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MimeTypeEnum.MimeType]]: ...
        UNSPECIFIED = typing___cast(MimeTypeEnum.MimeType, 0)
        UNKNOWN = typing___cast(MimeTypeEnum.MimeType, 1)
        IMAGE_JPEG = typing___cast(MimeTypeEnum.MimeType, 2)
        IMAGE_GIF = typing___cast(MimeTypeEnum.MimeType, 3)
        IMAGE_PNG = typing___cast(MimeTypeEnum.MimeType, 4)
        FLASH = typing___cast(MimeTypeEnum.MimeType, 5)
        TEXT_HTML = typing___cast(MimeTypeEnum.MimeType, 6)
        PDF = typing___cast(MimeTypeEnum.MimeType, 7)
        MSWORD = typing___cast(MimeTypeEnum.MimeType, 8)
        MSEXCEL = typing___cast(MimeTypeEnum.MimeType, 9)
        RTF = typing___cast(MimeTypeEnum.MimeType, 10)
        AUDIO_WAV = typing___cast(MimeTypeEnum.MimeType, 11)
        AUDIO_MP3 = typing___cast(MimeTypeEnum.MimeType, 12)
        HTML5_AD_ZIP = typing___cast(MimeTypeEnum.MimeType, 13)
    UNSPECIFIED = typing___cast(MimeTypeEnum.MimeType, 0)
    UNKNOWN = typing___cast(MimeTypeEnum.MimeType, 1)
    IMAGE_JPEG = typing___cast(MimeTypeEnum.MimeType, 2)
    IMAGE_GIF = typing___cast(MimeTypeEnum.MimeType, 3)
    IMAGE_PNG = typing___cast(MimeTypeEnum.MimeType, 4)
    FLASH = typing___cast(MimeTypeEnum.MimeType, 5)
    TEXT_HTML = typing___cast(MimeTypeEnum.MimeType, 6)
    PDF = typing___cast(MimeTypeEnum.MimeType, 7)
    MSWORD = typing___cast(MimeTypeEnum.MimeType, 8)
    MSEXCEL = typing___cast(MimeTypeEnum.MimeType, 9)
    RTF = typing___cast(MimeTypeEnum.MimeType, 10)
    AUDIO_WAV = typing___cast(MimeTypeEnum.MimeType, 11)
    AUDIO_MP3 = typing___cast(MimeTypeEnum.MimeType, 12)
    HTML5_AD_ZIP = typing___cast(MimeTypeEnum.MimeType, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MimeTypeEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.common.extensions_pb2 import (
    CallFeedItem as google___ads___googleads___v1___common___extensions_pb2___CallFeedItem,
    CalloutFeedItem as google___ads___googleads___v1___common___extensions_pb2___CalloutFeedItem,
    SitelinkFeedItem as google___ads___googleads___v1___common___extensions_pb2___SitelinkFeedItem,
)

from google.ads.google_ads.v1.proto.enums.keyword_match_type_pb2 import (
    KeywordMatchTypeEnum as google___ads___googleads___v1___enums___keyword_match_type_pb2___KeywordMatchTypeEnum,
)

from google.ads.google_ads.v1.proto.resources.ad_pb2 import (
    Ad as google___ads___googleads___v1___resources___ad_pb2___Ad,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetRecommendationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetRecommendationRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class ApplyRecommendationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool

    @property
    def operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ApplyRecommendationOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operations : typing___Optional[typing___Iterable[ApplyRecommendationOperation]] = None,
        partial_failure : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ApplyRecommendationRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operations",u"partial_failure"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operations",b"operations",u"partial_failure",b"partial_failure"]) -> None: ...

class ApplyRecommendationOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignBudgetParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def new_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            new_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.CampaignBudgetParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"new_budget_amount_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"new_budget_amount_micros"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"new_budget_amount_micros",b"new_budget_amount_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"new_budget_amount_micros",b"new_budget_amount_micros"]) -> None: ...

    class TextAdParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def ad(self) -> google___ads___googleads___v1___resources___ad_pb2___Ad: ...

        def __init__(self,
            *,
            ad : typing___Optional[google___ads___googleads___v1___resources___ad_pb2___Ad] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.TextAdParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"ad"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"ad"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"ad",b"ad"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"ad",b"ad"]) -> None: ...

    class KeywordParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        match_type = ... # type: google___ads___googleads___v1___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType

        @property
        def ad_group(self) -> google___protobuf___wrappers_pb2___StringValue: ...

        @property
        def cpc_bid_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            ad_group : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
            match_type : typing___Optional[google___ads___googleads___v1___enums___keyword_match_type_pb2___KeywordMatchTypeEnum.KeywordMatchType] = None,
            cpc_bid_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.KeywordParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"ad_group",u"cpc_bid_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",u"cpc_bid_micros",u"match_type"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"cpc_bid_micros",b"cpc_bid_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"ad_group",b"ad_group",u"cpc_bid_micros",b"cpc_bid_micros",u"match_type",b"match_type"]) -> None: ...

    class TargetCpaOptInParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def target_cpa_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        @property
        def new_campaign_budget_amount_micros(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            target_cpa_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            new_campaign_budget_amount_micros : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.TargetCpaOptInParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"new_campaign_budget_amount_micros",u"target_cpa_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"new_campaign_budget_amount_micros",u"target_cpa_micros"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"new_campaign_budget_amount_micros",b"new_campaign_budget_amount_micros",u"target_cpa_micros",b"target_cpa_micros"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"new_campaign_budget_amount_micros",b"new_campaign_budget_amount_micros",u"target_cpa_micros",b"target_cpa_micros"]) -> None: ...

    class CalloutExtensionParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def callout_extensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___extensions_pb2___CalloutFeedItem]: ...

        def __init__(self,
            *,
            callout_extensions : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___extensions_pb2___CalloutFeedItem]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.CalloutExtensionParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"callout_extensions"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"callout_extensions",b"callout_extensions"]) -> None: ...

    class CallExtensionParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def call_extensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___extensions_pb2___CallFeedItem]: ...

        def __init__(self,
            *,
            call_extensions : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___extensions_pb2___CallFeedItem]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.CallExtensionParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"call_extensions"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"call_extensions",b"call_extensions"]) -> None: ...

    class SitelinkExtensionParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def sitelink_extensions(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[google___ads___googleads___v1___common___extensions_pb2___SitelinkFeedItem]: ...

        def __init__(self,
            *,
            sitelink_extensions : typing___Optional[typing___Iterable[google___ads___googleads___v1___common___extensions_pb2___SitelinkFeedItem]] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.SitelinkExtensionParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"sitelink_extensions"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"sitelink_extensions",b"sitelink_extensions"]) -> None: ...

    class MoveUnusedBudgetParameters(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

        @property
        def budget_micros_to_move(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

        def __init__(self,
            *,
            budget_micros_to_move : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> ApplyRecommendationOperation.MoveUnusedBudgetParameters: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def HasField(self, field_name: typing_extensions___Literal[u"budget_micros_to_move"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros_to_move"]) -> None: ...
        else:
            def HasField(self, field_name: typing_extensions___Literal[u"budget_micros_to_move",b"budget_micros_to_move"]) -> bool: ...
            def ClearField(self, field_name: typing_extensions___Literal[u"budget_micros_to_move",b"budget_micros_to_move"]) -> None: ...

    resource_name = ... # type: typing___Text

    @property
    def campaign_budget(self) -> ApplyRecommendationOperation.CampaignBudgetParameters: ...

    @property
    def text_ad(self) -> ApplyRecommendationOperation.TextAdParameters: ...

    @property
    def keyword(self) -> ApplyRecommendationOperation.KeywordParameters: ...

    @property
    def target_cpa_opt_in(self) -> ApplyRecommendationOperation.TargetCpaOptInParameters: ...

    @property
    def callout_extension(self) -> ApplyRecommendationOperation.CalloutExtensionParameters: ...

    @property
    def call_extension(self) -> ApplyRecommendationOperation.CallExtensionParameters: ...

    @property
    def sitelink_extension(self) -> ApplyRecommendationOperation.SitelinkExtensionParameters: ...

    @property
    def move_unused_budget(self) -> ApplyRecommendationOperation.MoveUnusedBudgetParameters: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        campaign_budget : typing___Optional[ApplyRecommendationOperation.CampaignBudgetParameters] = None,
        text_ad : typing___Optional[ApplyRecommendationOperation.TextAdParameters] = None,
        keyword : typing___Optional[ApplyRecommendationOperation.KeywordParameters] = None,
        target_cpa_opt_in : typing___Optional[ApplyRecommendationOperation.TargetCpaOptInParameters] = None,
        callout_extension : typing___Optional[ApplyRecommendationOperation.CalloutExtensionParameters] = None,
        call_extension : typing___Optional[ApplyRecommendationOperation.CallExtensionParameters] = None,
        sitelink_extension : typing___Optional[ApplyRecommendationOperation.SitelinkExtensionParameters] = None,
        move_unused_budget : typing___Optional[ApplyRecommendationOperation.MoveUnusedBudgetParameters] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ApplyRecommendationOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"apply_parameters",u"call_extension",u"callout_extension",u"campaign_budget",u"keyword",u"move_unused_budget",u"sitelink_extension",u"target_cpa_opt_in",u"text_ad"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"apply_parameters",u"call_extension",u"callout_extension",u"campaign_budget",u"keyword",u"move_unused_budget",u"resource_name",u"sitelink_extension",u"target_cpa_opt_in",u"text_ad"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"apply_parameters",b"apply_parameters",u"call_extension",b"call_extension",u"callout_extension",b"callout_extension",u"campaign_budget",b"campaign_budget",u"keyword",b"keyword",u"move_unused_budget",b"move_unused_budget",u"sitelink_extension",b"sitelink_extension",u"target_cpa_opt_in",b"target_cpa_opt_in",u"text_ad",b"text_ad"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"apply_parameters",b"apply_parameters",u"call_extension",b"call_extension",u"callout_extension",b"callout_extension",u"campaign_budget",b"campaign_budget",u"keyword",b"keyword",u"move_unused_budget",b"move_unused_budget",u"resource_name",b"resource_name",u"sitelink_extension",b"sitelink_extension",u"target_cpa_opt_in",b"target_cpa_opt_in",u"text_ad",b"text_ad"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"apply_parameters",b"apply_parameters"]) -> typing_extensions___Literal["campaign_budget","text_ad","keyword","target_cpa_opt_in","callout_extension","call_extension","sitelink_extension","move_unused_budget"]: ...

class ApplyRecommendationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ApplyRecommendationResult]: ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[ApplyRecommendationResult]] = None,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ApplyRecommendationResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class ApplyRecommendationResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ApplyRecommendationResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class DismissRecommendationRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class DismissRecommendationOperation(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        resource_name = ... # type: typing___Text

        def __init__(self,
            *,
            resource_name : typing___Optional[typing___Text] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> DismissRecommendationRequest.DismissRecommendationOperation: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool

    @property
    def operations(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[DismissRecommendationRequest.DismissRecommendationOperation]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operations : typing___Optional[typing___Iterable[DismissRecommendationRequest.DismissRecommendationOperation]] = None,
        partial_failure : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DismissRecommendationRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operations",u"partial_failure"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operations",b"operations",u"partial_failure",b"partial_failure"]) -> None: ...

class DismissRecommendationResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class DismissRecommendationResult(google___protobuf___message___Message):
        DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
        resource_name = ... # type: typing___Text

        def __init__(self,
            *,
            resource_name : typing___Optional[typing___Text] = None,
            ) -> None: ...
        @classmethod
        def FromString(cls, s: bytes) -> DismissRecommendationResponse.DismissRecommendationResult: ...
        def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
        if sys.version_info >= (3,):
            def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
        else:
            def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...


    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[DismissRecommendationResponse.DismissRecommendationResult]: ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    def __init__(self,
        *,
        results : typing___Optional[typing___Iterable[DismissRecommendationResponse.DismissRecommendationResult]] = None,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> DismissRecommendationResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MonthOfYearEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MonthOfYear(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MonthOfYearEnum.MonthOfYear: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MonthOfYearEnum.MonthOfYear]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MonthOfYearEnum.MonthOfYear]]: ...
        UNSPECIFIED = typing___cast(MonthOfYearEnum.MonthOfYear, 0)
        UNKNOWN = typing___cast(MonthOfYearEnum.MonthOfYear, 1)
        JANUARY = typing___cast(MonthOfYearEnum.MonthOfYear, 2)
        FEBRUARY = typing___cast(MonthOfYearEnum.MonthOfYear, 3)
        MARCH = typing___cast(MonthOfYearEnum.MonthOfYear, 4)
        APRIL = typing___cast(MonthOfYearEnum.MonthOfYear, 5)
        MAY = typing___cast(MonthOfYearEnum.MonthOfYear, 6)
        JUNE = typing___cast(MonthOfYearEnum.MonthOfYear, 7)
        JULY = typing___cast(MonthOfYearEnum.MonthOfYear, 8)
        AUGUST = typing___cast(MonthOfYearEnum.MonthOfYear, 9)
        SEPTEMBER = typing___cast(MonthOfYearEnum.MonthOfYear, 10)
        OCTOBER = typing___cast(MonthOfYearEnum.MonthOfYear, 11)
        NOVEMBER = typing___cast(MonthOfYearEnum.MonthOfYear, 12)
        DECEMBER = typing___cast(MonthOfYearEnum.MonthOfYear, 13)
    UNSPECIFIED = typing___cast(MonthOfYearEnum.MonthOfYear, 0)
    UNKNOWN = typing___cast(MonthOfYearEnum.MonthOfYear, 1)
    JANUARY = typing___cast(MonthOfYearEnum.MonthOfYear, 2)
    FEBRUARY = typing___cast(MonthOfYearEnum.MonthOfYear, 3)
    MARCH = typing___cast(MonthOfYearEnum.MonthOfYear, 4)
    APRIL = typing___cast(MonthOfYearEnum.MonthOfYear, 5)
    MAY = typing___cast(MonthOfYearEnum.MonthOfYear, 6)
    JUNE = typing___cast(MonthOfYearEnum.MonthOfYear, 7)
    JULY = typing___cast(MonthOfYearEnum.MonthOfYear, 8)
    AUGUST = typing___cast(MonthOfYearEnum.MonthOfYear, 9)
    SEPTEMBER = typing___cast(MonthOfYearEnum.MonthOfYear, 10)
    OCTOBER = typing___cast(MonthOfYearEnum.MonthOfYear, 11)
    NOVEMBER = typing___cast(MonthOfYearEnum.MonthOfYear, 12)
    DECEMBER = typing___cast(MonthOfYearEnum.MonthOfYear, 13)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MonthOfYearEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class CampaignErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class CampaignError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> CampaignErrorEnum.CampaignError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[CampaignErrorEnum.CampaignError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, CampaignErrorEnum.CampaignError]]: ...
        UNSPECIFIED = typing___cast(CampaignErrorEnum.CampaignError, 0)
        UNKNOWN = typing___cast(CampaignErrorEnum.CampaignError, 1)
        CANNOT_TARGET_CONTENT_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 3)
        CANNOT_TARGET_SEARCH_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 4)
        CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = typing___cast(CampaignErrorEnum.CampaignError, 5)
        CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = typing___cast(CampaignErrorEnum.CampaignError, 6)
        CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 7)
        CANNOT_TARGET_PARTNER_SEARCH_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 8)
        CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = typing___cast(CampaignErrorEnum.CampaignError, 9)
        CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = typing___cast(CampaignErrorEnum.CampaignError, 10)
        CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = typing___cast(CampaignErrorEnum.CampaignError, 11)
        DUPLICATE_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignError, 12)
        INCOMPATIBLE_CAMPAIGN_FIELD = typing___cast(CampaignErrorEnum.CampaignError, 13)
        INVALID_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignError, 14)
        INVALID_AD_SERVING_OPTIMIZATION_STATUS = typing___cast(CampaignErrorEnum.CampaignError, 15)
        INVALID_TRACKING_URL = typing___cast(CampaignErrorEnum.CampaignError, 16)
        CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 17)
        MAX_IMPRESSIONS_NOT_IN_RANGE = typing___cast(CampaignErrorEnum.CampaignError, 18)
        TIME_UNIT_NOT_SUPPORTED = typing___cast(CampaignErrorEnum.CampaignError, 19)
        INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = typing___cast(CampaignErrorEnum.CampaignError, 20)
        BUDGET_CANNOT_BE_SHARED = typing___cast(CampaignErrorEnum.CampaignError, 21)
        CAMPAIGN_CANNOT_USE_SHARED_BUDGET = typing___cast(CampaignErrorEnum.CampaignError, 22)
        CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = typing___cast(CampaignErrorEnum.CampaignError, 23)
        CAMPAIGN_LABEL_DOES_NOT_EXIST = typing___cast(CampaignErrorEnum.CampaignError, 24)
        CAMPAIGN_LABEL_ALREADY_EXISTS = typing___cast(CampaignErrorEnum.CampaignError, 25)
        MISSING_SHOPPING_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 26)
        INVALID_SHOPPING_SALES_COUNTRY = typing___cast(CampaignErrorEnum.CampaignError, 27)
        MISSING_UNIVERSAL_APP_CAMPAIGN_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 30)
        ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(CampaignErrorEnum.CampaignError, 31)
        INVALID_ADVERTISING_CHANNEL_SUB_TYPE = typing___cast(CampaignErrorEnum.CampaignError, 32)
        AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = typing___cast(CampaignErrorEnum.CampaignError, 33)
        CANNOT_SET_AD_ROTATION_MODE = typing___cast(CampaignErrorEnum.CampaignError, 34)
        CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(CampaignErrorEnum.CampaignError, 35)
        CANNOT_SET_DATE_TO_PAST = typing___cast(CampaignErrorEnum.CampaignError, 36)
        MISSING_HOTEL_CUSTOMER_LINK = typing___cast(CampaignErrorEnum.CampaignError, 37)
        INVALID_HOTEL_CUSTOMER_LINK = typing___cast(CampaignErrorEnum.CampaignError, 38)
        MISSING_HOTEL_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 39)
        CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = typing___cast(CampaignErrorEnum.CampaignError, 40)
        APP_NOT_FOUND = typing___cast(CampaignErrorEnum.CampaignError, 41)
        SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = typing___cast(CampaignErrorEnum.CampaignError, 42)
        MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = typing___cast(CampaignErrorEnum.CampaignError, 43)
    UNSPECIFIED = typing___cast(CampaignErrorEnum.CampaignError, 0)
    UNKNOWN = typing___cast(CampaignErrorEnum.CampaignError, 1)
    CANNOT_TARGET_CONTENT_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 3)
    CANNOT_TARGET_SEARCH_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 4)
    CANNOT_TARGET_SEARCH_NETWORK_WITHOUT_GOOGLE_SEARCH = typing___cast(CampaignErrorEnum.CampaignError, 5)
    CANNOT_TARGET_GOOGLE_SEARCH_FOR_CPM_CAMPAIGN = typing___cast(CampaignErrorEnum.CampaignError, 6)
    CAMPAIGN_MUST_TARGET_AT_LEAST_ONE_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 7)
    CANNOT_TARGET_PARTNER_SEARCH_NETWORK = typing___cast(CampaignErrorEnum.CampaignError, 8)
    CANNOT_TARGET_CONTENT_NETWORK_ONLY_WITH_CRITERIA_LEVEL_BIDDING_STRATEGY = typing___cast(CampaignErrorEnum.CampaignError, 9)
    CAMPAIGN_DURATION_MUST_CONTAIN_ALL_RUNNABLE_TRIALS = typing___cast(CampaignErrorEnum.CampaignError, 10)
    CANNOT_MODIFY_FOR_TRIAL_CAMPAIGN = typing___cast(CampaignErrorEnum.CampaignError, 11)
    DUPLICATE_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignError, 12)
    INCOMPATIBLE_CAMPAIGN_FIELD = typing___cast(CampaignErrorEnum.CampaignError, 13)
    INVALID_CAMPAIGN_NAME = typing___cast(CampaignErrorEnum.CampaignError, 14)
    INVALID_AD_SERVING_OPTIMIZATION_STATUS = typing___cast(CampaignErrorEnum.CampaignError, 15)
    INVALID_TRACKING_URL = typing___cast(CampaignErrorEnum.CampaignError, 16)
    CANNOT_SET_BOTH_TRACKING_URL_TEMPLATE_AND_TRACKING_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 17)
    MAX_IMPRESSIONS_NOT_IN_RANGE = typing___cast(CampaignErrorEnum.CampaignError, 18)
    TIME_UNIT_NOT_SUPPORTED = typing___cast(CampaignErrorEnum.CampaignError, 19)
    INVALID_OPERATION_IF_SERVING_STATUS_HAS_ENDED = typing___cast(CampaignErrorEnum.CampaignError, 20)
    BUDGET_CANNOT_BE_SHARED = typing___cast(CampaignErrorEnum.CampaignError, 21)
    CAMPAIGN_CANNOT_USE_SHARED_BUDGET = typing___cast(CampaignErrorEnum.CampaignError, 22)
    CANNOT_CHANGE_BUDGET_ON_CAMPAIGN_WITH_TRIALS = typing___cast(CampaignErrorEnum.CampaignError, 23)
    CAMPAIGN_LABEL_DOES_NOT_EXIST = typing___cast(CampaignErrorEnum.CampaignError, 24)
    CAMPAIGN_LABEL_ALREADY_EXISTS = typing___cast(CampaignErrorEnum.CampaignError, 25)
    MISSING_SHOPPING_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 26)
    INVALID_SHOPPING_SALES_COUNTRY = typing___cast(CampaignErrorEnum.CampaignError, 27)
    MISSING_UNIVERSAL_APP_CAMPAIGN_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 30)
    ADVERTISING_CHANNEL_TYPE_NOT_AVAILABLE_FOR_ACCOUNT_TYPE = typing___cast(CampaignErrorEnum.CampaignError, 31)
    INVALID_ADVERTISING_CHANNEL_SUB_TYPE = typing___cast(CampaignErrorEnum.CampaignError, 32)
    AT_LEAST_ONE_CONVERSION_MUST_BE_SELECTED = typing___cast(CampaignErrorEnum.CampaignError, 33)
    CANNOT_SET_AD_ROTATION_MODE = typing___cast(CampaignErrorEnum.CampaignError, 34)
    CANNOT_MODIFY_START_DATE_IF_ALREADY_STARTED = typing___cast(CampaignErrorEnum.CampaignError, 35)
    CANNOT_SET_DATE_TO_PAST = typing___cast(CampaignErrorEnum.CampaignError, 36)
    MISSING_HOTEL_CUSTOMER_LINK = typing___cast(CampaignErrorEnum.CampaignError, 37)
    INVALID_HOTEL_CUSTOMER_LINK = typing___cast(CampaignErrorEnum.CampaignError, 38)
    MISSING_HOTEL_SETTING = typing___cast(CampaignErrorEnum.CampaignError, 39)
    CANNOT_USE_SHARED_CAMPAIGN_BUDGET_WHILE_PART_OF_CAMPAIGN_GROUP = typing___cast(CampaignErrorEnum.CampaignError, 40)
    APP_NOT_FOUND = typing___cast(CampaignErrorEnum.CampaignError, 41)
    SHOPPING_ENABLE_LOCAL_NOT_SUPPORTED_FOR_CAMPAIGN_TYPE = typing___cast(CampaignErrorEnum.CampaignError, 42)
    MERCHANT_NOT_ALLOWED_FOR_COMPARISON_LISTING_ADS = typing___cast(CampaignErrorEnum.CampaignError, 43)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> CampaignErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v2.proto.enums.media_type_pb2 import (
    MediaTypeEnum as google___ads___googleads___v2___enums___media_type_pb2___MediaTypeEnum,
)

from google.ads.google_ads.v2.proto.enums.mime_type_pb2 import (
    MimeTypeEnum as google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    BytesValue as google___protobuf___wrappers_pb2___BytesValue,
    Int64Value as google___protobuf___wrappers_pb2___Int64Value,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class MediaFile(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text
    type = ... # type: google___ads___googleads___v2___enums___media_type_pb2___MediaTypeEnum.MediaType
    mime_type = ... # type: google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum.MimeType

    @property
    def id(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def source_url(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def name(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def file_size(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def image(self) -> MediaImage: ...

    @property
    def media_bundle(self) -> MediaBundle: ...

    @property
    def audio(self) -> MediaAudio: ...

    @property
    def video(self) -> MediaVideo: ...

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        id : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        type : typing___Optional[google___ads___googleads___v2___enums___media_type_pb2___MediaTypeEnum.MediaType] = None,
        mime_type : typing___Optional[google___ads___googleads___v2___enums___mime_type_pb2___MimeTypeEnum.MimeType] = None,
        source_url : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        name : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        file_size : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        image : typing___Optional[MediaImage] = None,
        media_bundle : typing___Optional[MediaBundle] = None,
        audio : typing___Optional[MediaAudio] = None,
        video : typing___Optional[MediaVideo] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaFile: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"audio",u"file_size",u"id",u"image",u"media_bundle",u"mediatype",u"name",u"source_url",u"video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"audio",u"file_size",u"id",u"image",u"media_bundle",u"mediatype",u"mime_type",u"name",u"resource_name",u"source_url",u"type",u"video"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"audio",b"audio",u"file_size",b"file_size",u"id",b"id",u"image",b"image",u"media_bundle",b"media_bundle",u"mediatype",b"mediatype",u"name",b"name",u"source_url",b"source_url",u"video",b"video"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"audio",b"audio",u"file_size",b"file_size",u"id",b"id",u"image",b"image",u"media_bundle",b"media_bundle",u"mediatype",b"mediatype",u"mime_type",b"mime_type",u"name",b"name",u"resource_name",b"resource_name",u"source_url",b"source_url",u"type",b"type",u"video",b"video"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"mediatype",b"mediatype"]) -> typing_extensions___Literal["image","media_bundle","audio","video"]: ...

class MediaImage(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...

    def __init__(self,
        *,
        data : typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaImage: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...

class MediaBundle(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def data(self) -> google___protobuf___wrappers_pb2___BytesValue: ...

    def __init__(self,
        *,
        data : typing___Optional[google___protobuf___wrappers_pb2___BytesValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaBundle: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"data",b"data"]) -> None: ...

class MediaAudio(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_duration_millis(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    def __init__(self,
        *,
        ad_duration_millis : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaAudio: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis"]) -> None: ...

class MediaVideo(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def ad_duration_millis(self) -> google___protobuf___wrappers_pb2___Int64Value: ...

    @property
    def youtube_video_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def advertising_id_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def isci_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        ad_duration_millis : typing___Optional[google___protobuf___wrappers_pb2___Int64Value] = None,
        youtube_video_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        advertising_id_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        isci_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaVideo: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",u"advertising_id_code",u"isci_code",u"youtube_video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",u"advertising_id_code",u"isci_code",u"youtube_video_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis",u"advertising_id_code",b"advertising_id_code",u"isci_code",b"isci_code",u"youtube_video_id",b"youtube_video_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"ad_duration_millis",b"ad_duration_millis",u"advertising_id_code",b"advertising_id_code",u"isci_code",b"isci_code",u"youtube_video_id",b"youtube_video_id"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.resources.billing_setup_pb2 import (
    BillingSetup as google___ads___googleads___v1___resources___billing_setup_pb2___BillingSetup,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class GetBillingSetupRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GetBillingSetupRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...

class MutateBillingSetupRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text

    @property
    def operation(self) -> BillingSetupOperation: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        operation : typing___Optional[BillingSetupOperation] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateBillingSetupRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",u"operation"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"operation",b"operation"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"customer_id",b"customer_id",u"operation",b"operation"]) -> None: ...

class BillingSetupOperation(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    remove = ... # type: typing___Text

    @property
    def create(self) -> google___ads___googleads___v1___resources___billing_setup_pb2___BillingSetup: ...

    def __init__(self,
        *,
        create : typing___Optional[google___ads___googleads___v1___resources___billing_setup_pb2___BillingSetup] = None,
        remove : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> BillingSetupOperation: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"remove"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",u"operation",u"remove"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"remove",b"remove"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"create",b"create",u"operation",b"operation",u"remove",b"remove"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"operation",b"operation"]) -> typing_extensions___Literal["create","remove"]: ...

class MutateBillingSetupResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def result(self) -> MutateBillingSetupResult: ...

    def __init__(self,
        *,
        result : typing___Optional[MutateBillingSetupResult] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateBillingSetupResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"result"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"result",b"result"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"result",b"result"]) -> None: ...

class MutateBillingSetupResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    resource_name = ... # type: typing___Text

    def __init__(self,
        *,
        resource_name : typing___Optional[typing___Text] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MutateBillingSetupResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"resource_name",b"resource_name"]) -> None: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Tuple as typing___Tuple,
    cast as typing___cast,
)


class MediaFileErrorEnum(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class MediaFileError(int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: int) -> str: ...
        @classmethod
        def Value(cls, name: str) -> MediaFileErrorEnum.MediaFileError: ...
        @classmethod
        def keys(cls) -> typing___List[str]: ...
        @classmethod
        def values(cls) -> typing___List[MediaFileErrorEnum.MediaFileError]: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[str, MediaFileErrorEnum.MediaFileError]]: ...
        UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 0)
        UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileError, 1)
        CANNOT_CREATE_STANDARD_ICON = typing___cast(MediaFileErrorEnum.MediaFileError, 2)
        CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(MediaFileErrorEnum.MediaFileError, 3)
        CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(MediaFileErrorEnum.MediaFileError, 4)
        DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileError, 5)
        EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileError, 6)
        RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(MediaFileErrorEnum.MediaFileError, 7)
        FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 8)
        INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 9)
        INVALID_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 10)
        INVALID_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 11)
        INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 12)
        INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 13)
        INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 14)
        MEDIA_FILE_FAILED_TRANSCODING = typing___cast(MediaFileErrorEnum.MediaFileError, 15)
        MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileError, 16)
        MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 17)
        NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 18)
        NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 19)
        TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileError, 20)
        UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 21)
        YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(MediaFileErrorEnum.MediaFileError, 22)
        YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(MediaFileErrorEnum.MediaFileError, 23)
        YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(MediaFileErrorEnum.MediaFileError, 24)
    UNSPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 0)
    UNKNOWN = typing___cast(MediaFileErrorEnum.MediaFileError, 1)
    CANNOT_CREATE_STANDARD_ICON = typing___cast(MediaFileErrorEnum.MediaFileError, 2)
    CANNOT_SELECT_STANDARD_ICON_WITH_OTHER_TYPES = typing___cast(MediaFileErrorEnum.MediaFileError, 3)
    CANNOT_SPECIFY_MEDIA_FILE_ID_AND_DATA = typing___cast(MediaFileErrorEnum.MediaFileError, 4)
    DUPLICATE_MEDIA = typing___cast(MediaFileErrorEnum.MediaFileError, 5)
    EMPTY_FIELD = typing___cast(MediaFileErrorEnum.MediaFileError, 6)
    RESOURCE_REFERENCED_IN_MULTIPLE_OPS = typing___cast(MediaFileErrorEnum.MediaFileError, 7)
    FIELD_NOT_SUPPORTED_FOR_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 8)
    INVALID_MEDIA_FILE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 9)
    INVALID_MEDIA_SUB_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 10)
    INVALID_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 11)
    INVALID_MIME_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 12)
    INVALID_REFERENCE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 13)
    INVALID_YOU_TUBE_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 14)
    MEDIA_FILE_FAILED_TRANSCODING = typing___cast(MediaFileErrorEnum.MediaFileError, 15)
    MEDIA_NOT_TRANSCODED = typing___cast(MediaFileErrorEnum.MediaFileError, 16)
    MEDIA_TYPE_DOES_NOT_MATCH_MEDIA_FILE_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 17)
    NO_FIELDS_SPECIFIED = typing___cast(MediaFileErrorEnum.MediaFileError, 18)
    NULL_REFERENCE_ID_AND_MEDIA_ID = typing___cast(MediaFileErrorEnum.MediaFileError, 19)
    TOO_LONG = typing___cast(MediaFileErrorEnum.MediaFileError, 20)
    UNSUPPORTED_TYPE = typing___cast(MediaFileErrorEnum.MediaFileError, 21)
    YOU_TUBE_SERVICE_UNAVAILABLE = typing___cast(MediaFileErrorEnum.MediaFileError, 22)
    YOU_TUBE_VIDEO_HAS_NON_POSITIVE_DURATION = typing___cast(MediaFileErrorEnum.MediaFileError, 23)
    YOU_TUBE_VIDEO_NOT_FOUND = typing___cast(MediaFileErrorEnum.MediaFileError, 24)


    def __init__(self,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> MediaFileErrorEnum: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...



import grpc  # type: ignore
from google.ads.google_ads.v1.services.transports.customer_service_grpc_transport import CustomerServiceGrpcTransport
from google.auth.credentials import Credentials  # type: ignore
from google.api_core.gapic_v1.client_info import ClientInfo  # type: ignore
from google.api_core.retry import Retry  # type: ignore
from typing import Optional, Dict, Any, List, Sequence, Tuple, Union, Callable, ClassVar
from google.ads.google_ads.v1.proto.resources.customer_pb2 import Customer
from google.ads.google_ads.v1.proto.services.customer_service_pb2 import CustomerOperation, MutateCustomerResponse, \
    ListAccessibleCustomersResponse, CreateCustomerClientResponse


class CustomerServiceClient:
    SERVICE_ADDRESS: ClassVar[str] = ...
    @classmethod
    def from_service_account_file(cls, filename: str, *args: Any, **kwargs: Any) -> CustomerServiceClient: ...
    @classmethod
    def from_service_account_json(cls, filename: str, *args: Any, **kwargs: Any) -> CustomerServiceClient: ...
    @classmethod
    def customer_path(cls, customer: Any): ...
    transport: Union[CustomerServiceGrpcTransport, Callable[[Credentials, type], CustomerServiceGrpcTransport]] = ...
    def __init__(self, transport: Optional[Union[CustomerServiceGrpcTransport, Callable[[Credentials, type], CustomerServiceGrpcTransport]]] = ..., channel: Optional[grpc.Channel] = ..., credentials: Optional[Credentials] = ..., client_config: Optional[Dict[Any, Any]] = ..., client_info: Optional[ClientInfo] = ...) -> None: ...
    def get_customer(self, resource_name: str, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> Customer: ...
    def mutate_customer(self, customer_id: str, operation_: Union[Dict[Any, Any], CustomerOperation], validate_only: Optional[bool] = ..., retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> MutateCustomerResponse: ...
    def list_accessible_customers(self, retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> ListAccessibleCustomersResponse: ...
    def create_customer_client(self, customer_id: str, customer_client: Union[Dict[Any, Any], Customer], retry: Optional[Retry] = ..., timeout: Optional[float] = ..., metadata: Optional[Sequence[Tuple[str, str]]] = ...) -> CreateCustomerClientResponse: ...



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.ads.google_ads.v1.proto.enums.conversion_adjustment_type_pb2 import (
    ConversionAdjustmentTypeEnum as google___ads___googleads___v1___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum,
)

from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.internal.containers import (
    RepeatedCompositeFieldContainer as google___protobuf___internal___containers___RepeatedCompositeFieldContainer,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from google.protobuf.wrappers_pb2 import (
    DoubleValue as google___protobuf___wrappers_pb2___DoubleValue,
    StringValue as google___protobuf___wrappers_pb2___StringValue,
)

from google.rpc.status_pb2 import (
    Status as google___rpc___status_pb2___Status,
)

from typing import (
    Iterable as typing___Iterable,
    Optional as typing___Optional,
    Text as typing___Text,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


class UploadConversionAdjustmentsRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    customer_id = ... # type: typing___Text
    partial_failure = ... # type: bool
    validate_only = ... # type: bool

    @property
    def conversion_adjustments(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ConversionAdjustment]: ...

    def __init__(self,
        *,
        customer_id : typing___Optional[typing___Text] = None,
        conversion_adjustments : typing___Optional[typing___Iterable[ConversionAdjustment]] = None,
        partial_failure : typing___Optional[bool] = None,
        validate_only : typing___Optional[bool] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UploadConversionAdjustmentsRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_adjustments",u"customer_id",u"partial_failure",u"validate_only"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_adjustments",b"conversion_adjustments",u"customer_id",b"customer_id",u"partial_failure",b"partial_failure",u"validate_only",b"validate_only"]) -> None: ...

class UploadConversionAdjustmentsResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def partial_failure_error(self) -> google___rpc___status_pb2___Status: ...

    @property
    def results(self) -> google___protobuf___internal___containers___RepeatedCompositeFieldContainer[ConversionAdjustmentResult]: ...

    def __init__(self,
        *,
        partial_failure_error : typing___Optional[google___rpc___status_pb2___Status] = None,
        results : typing___Optional[typing___Iterable[ConversionAdjustmentResult]] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> UploadConversionAdjustmentsResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",u"results"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"partial_failure_error",b"partial_failure_error",u"results",b"results"]) -> None: ...

class ConversionAdjustment(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    adjustment_type = ... # type: google___ads___googleads___v1___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentType

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def adjustment_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def restatement_value(self) -> RestatementValue: ...

    @property
    def gclid_date_time_pair(self) -> GclidDateTimePair: ...

    @property
    def order_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        adjustment_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        adjustment_type : typing___Optional[google___ads___googleads___v1___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentType] = None,
        restatement_value : typing___Optional[RestatementValue] = None,
        gclid_date_time_pair : typing___Optional[GclidDateTimePair] = None,
        order_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionAdjustment: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",u"conversion_action",u"conversion_identifier",u"gclid_date_time_pair",u"order_id",u"restatement_value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",u"adjustment_type",u"conversion_action",u"conversion_identifier",u"gclid_date_time_pair",u"order_id",u"restatement_value"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",b"adjustment_date_time",u"conversion_action",b"conversion_action",u"conversion_identifier",b"conversion_identifier",u"gclid_date_time_pair",b"gclid_date_time_pair",u"order_id",b"order_id",u"restatement_value",b"restatement_value"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",b"adjustment_date_time",u"adjustment_type",b"adjustment_type",u"conversion_action",b"conversion_action",u"conversion_identifier",b"conversion_identifier",u"gclid_date_time_pair",b"gclid_date_time_pair",u"order_id",b"order_id",u"restatement_value",b"restatement_value"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"conversion_identifier",b"conversion_identifier"]) -> typing_extensions___Literal["gclid_date_time_pair","order_id"]: ...

class RestatementValue(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def adjusted_value(self) -> google___protobuf___wrappers_pb2___DoubleValue: ...

    @property
    def currency_code(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        adjusted_value : typing___Optional[google___protobuf___wrappers_pb2___DoubleValue] = None,
        currency_code : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> RestatementValue: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"adjusted_value",u"currency_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjusted_value",u"currency_code"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"adjusted_value",b"adjusted_value",u"currency_code",b"currency_code"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjusted_value",b"adjusted_value",u"currency_code",b"currency_code"]) -> None: ...

class GclidDateTimePair(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...

    @property
    def gclid(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def conversion_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        gclid : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        conversion_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> GclidDateTimePair: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_date_time",u"gclid"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_date_time",u"gclid"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"conversion_date_time",b"conversion_date_time",u"gclid",b"gclid"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"conversion_date_time",b"conversion_date_time",u"gclid",b"gclid"]) -> None: ...

class ConversionAdjustmentResult(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    adjustment_type = ... # type: google___ads___googleads___v1___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentType

    @property
    def conversion_action(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def adjustment_date_time(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    @property
    def gclid_date_time_pair(self) -> GclidDateTimePair: ...

    @property
    def order_id(self) -> google___protobuf___wrappers_pb2___StringValue: ...

    def __init__(self,
        *,
        conversion_action : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        adjustment_date_time : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        adjustment_type : typing___Optional[google___ads___googleads___v1___enums___conversion_adjustment_type_pb2___ConversionAdjustmentTypeEnum.ConversionAdjustmentType] = None,
        gclid_date_time_pair : typing___Optional[GclidDateTimePair] = None,
        order_id : typing___Optional[google___protobuf___wrappers_pb2___StringValue] = None,
        ) -> None: ...
    @classmethod
    def FromString(cls, s: bytes) -> ConversionAdjustmentResult: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",u"conversion_action",u"conversion_identifier",u"gclid_date_time_pair",u"order_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",u"adjustment_type",u"conversion_action",u"conversion_identifier",u"gclid_date_time_pair",u"order_id"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",b"adjustment_date_time",u"conversion_action",b"conversion_action",u"conversion_identifier",b"conversion_identifier",u"gclid_date_time_pair",b"gclid_date_time_pair",u"order_id",b"order_id"]) -> bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"adjustment_date_time",b"adjustment_date_time",u"adjustment_type",b"adjustment_type",u"conversion_action",b"conversion_action",u"conversion_identifier",b"conversion_identifier",u"gclid_date_time_pair",b"gclid_date_time_pair",u"order_id",b"order_id"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"conversion_identifier",b"conversion_identifier"]) -> typing_extensions___Literal["gclid_date_time_pair","order_id"]: ...
